"""OLPC Sugar Graphical "Shell" Interface

Provides the shell-level operations for managing
the OLPC laptop computers.  It interacts heavily
with (and depends upon) the Sugar UI libraries.

This is a "graphical" shell, the name does not
refer to a command-line "shell" interface.
"""

# Copyright (C) 2006-2007, Red Hat, Inc.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
